// Define the dimensions of the visualization.
const width = 1000;
const height = 1000;

// Create the SVG canvas.
const svg = d3.select("#network-graph")
  .attr("width", width)
  .attr("height", height);

// Define a color scale for the targets
const color = d3.scaleOrdinal()
  .domain(['Graduate', 'Enrolled', 'Dropout'])
  .range(['green', 'blue', 'red']);

function handleBigCircleClick(category) {
  svg.selectAll(`.nodes circle.${category}`)
    .style("opacity", function(d) {
      return d3.select(this).style("opacity") === "1" ? "0" : "1";
    });
}

// Create the big circles with the click event handler
const bigCirclesData = [
  { category: "graduate", label: "Graduate", color: "green" },
  { category: "enrolled", label: "Enrolled", color: "blue" },
  { category: "dropout", label: "Dropout", color: "red" },
];


const bigCircles = svg.selectAll(".big-circle")
  .data(bigCirclesData)
  .enter()
  .append("circle")
  .attr("class", "big-circle")
  .attr("cx", (d, i) => width / 4 * (i + 1))
  .attr("cy", height / 8)
  .attr("r", 50)
  .attr("fill", d => d.color)
  .style("cursor", "pointer")
  .on("click", d => handleBigCircleClick(d.category));

// Load the data.
d3.csv("data.csv")
  .then(function(data) {
    // Create the nodes for each student.
    const node = svg.append("g")
      .attr("class", "nodes")
      .selectAll("circle")
      .data(data)
      .enter().append("circle")
      .attr("r", 10)
      .attr("class", function(d) { return d.Target.toLowerCase().replace(' ', '-'); })
      .attr("fill", function(d) { return color(d.Target); })
      .style("opacity", 0)
      .on("mouseover", function(d) {
        // Show student info on mouseover.
        console.log(d);
      });

    // Define the force simulation.
    const simulation = d3.forceSimulation(data)
      .force("charge", d3.forceManyBody().strength(-30))
      .force("x", d3.forceX(width / 2).strength(0.5))
      .force("y", d3.forceY(height / 2).strength(0.5))
      .force("collision", d3.forceCollide().radius(11));

    // Update the nodes on each tick of the simulation.
    simulation.on("tick", function() {
      node.attr("cx", function(d) { return d.x; })
          .attr("cy", function(d) { return d.y; });
    });

    // Move the big circles to the front
    bigCircles.raise();
  })
  .catch(function(error) {
    console.log(error);
  });
